########
profiles
########

.. toctree::
   :maxdepth: 1

   opentype
   universal
   adobefonts
   googlefonts
   fontval
   shared_conditions
   ufo_sources



.. automodule:: fontbakery.profiles
   :members:
   :undoc-members:
